
## Data Components

| Data Category   | Data Component Name           | Dataitem Input | Data Function                                                                                       | Default Frequency |
|-----------------|-------------------------------| --- |-----------------------------------------------------------------------------------------------------| --- |
| Market          | High                          | ❌ | [`prismstudio.market.high`](<#prismstudio.market.high>)                                             | Business Day |
| Market          | Low                           | ❌ | [`prismstudio.market.low`](<#prismstudio.market.low>)                                               | Business Day |
| Market          | Open                          | ❌ | [`prismstudio.market.open`](<#prismstudio.market.open>)                                             | Business Day |
| Market          | Close                         | ❌ | [`prismstudio.market.close`](<#prismstudio.market.close>)                                           | Business Day |
| Market          | Ask                           | ❌ | [`prismstudio.market.ask`](<#prismstudio.market.ask>)                                               | Business Day |
| Market          | Bid                           | ❌ | [`prismstudio.market.bid`](<#prismstudio.market.bid>)                                               | Business Day |
| Market          | Volume                        | ❌ | [`prismstudio.market.volume`](<#prismstudio.market.volume>)                                         | Business Day |
| Market          | VWAP                          | ❌ | [`prismstudio.market.vwap`](<#prismstudio.market.vwap>)                                             | Business Day |
| Market          | Total Return Index            | ❌ | [`prismstudio.market.totalreturnindex`](<#prismstudio.market.totalreturnindex>)                     | Business Day |
| Market          | Market Capitalization         | ❌ | [`prismstudio.market.market_cap`](<#prismstudio.market.market_cap>)                                 | Day |
| Market          | Shares Outstanding            | ❌ | [`prismstudio.market.shares_outstanding`](<#prismstudio.market.shares_outstanding>)                 | Day |
| Market          | Enterprise Value              | ❌ | [`prismstudio.market.enterprise_value`](<#prismstudio.market.enterprise_value>)                     | Day |
| Market          | Diluted Market Capitalization | ❌ | [`prismstudio.market.diluted_market_cap`](<#prismstudio.market.diluted_market_cap>)                 | Day |
| Market          | Dividend                      | ❌ | [`prismstudio.market.dividend`](<#prismstudio.financial.eps>)                                       | Business Day |
| Market          | Dividend Adjustment Factor    | ❌ | [`prismstudio.market.dividend_adjustment_factor`](<#prismstudio.market.dividend_adjustment_factor>) | Business Day |
| Market          | Split                         | ❌ | [`prismstudio.market.split`](<#prismstudio.market.split>)                                           | Aperiodic Day |
| Market          | Split Adjustment Factor       | ❌ | [`prismstudio.market.split_adjustment_factor`](<#prismstudio.market.split_adjustment_factor>)       | Aperiodic Day |
| Market          | Exchange Rate                 | ❌ | [`prismstudio.market.exchange_rate`](<#prismstudio.market.exchange_rate>)                           | Day |
| Market          | Short Interest                | ✔️ | [`prismstudio.market.short_interest`](<#prismstudio.market.short_interest>)                         | Business Day |
| Financial       | Balance Sheet                 | ✔️ | [`prismstudio.financial.balance_sheet`](<#prismstudio.financial.balance_sheet>)                     | Aperiodic Day |
| Financial       | Cash Flow                     | ✔️ | [`prismstudio.financial.cash_flow`](<#prismstudio.financial.cash_flow>)                             | Aperiodic Day |
| Financial       | DPS                           | ✔️ | [`prismstudio.financial.dps`](<#prismstudio.financial.dps>)                                         | Aperiodic Day |
| Financial       | EPS                           | ✔️ | [`prismstudio.financial.eps`](<#prismstudio.financial.eps>)                                         | Aperiodic Day |
| Financial       | Income Statement              | ✔️ | [`prismstudio.financial.income_statement`](<#prismstudio.financial.income_statement>)               | Aperiodic Day |
| Financial       | Segment                       | ✔️ | [`prismstudio.financial.segment`](<#prismstudio.financial.segment>)                                 | Aperiodic Day |
| Financial       | Ratio                         | ✔️ | [`prismstudio.financial.ratio`](<#prismstudio.financial.ratio>)                                     | Aperiodic Day |
| Financial       | Commitment                    | ✔️ | [`prismstudio.financial.commitment`](<#prismstudio.financial.commitment>)                           | Aperiodic Day |
| Financial       | Option                        | ✔️ | [`prismstudio.financial.option`](<#prismstudio.financial.option>)                                   | Aperiodic Day |
| Financial       | Pension                       | ✔️ | [`prismstudio.financial.pension`](<#prismstudio.financial.pension>)                                 | Aperiodic Day |
| Financial       | Industry                      | ✔️ | [`prismstudio.financial.industry`](<#prismstudio.financial.industry>)                               | Aperiodic Day |
| Estimate        | Actual                        | ✔️ | [`prismstudio.estimate.actual`](<#prismstudio.estimate.actual>)                                     | Aperiodic |
| Estimate        | Consensus                     | ✔️ | [`prismstudio.estimate.consensus`](<#prismstudio.estimate.consensus>)                               | Aperiodic |
| Estimate        | Guidance                      | ✔️ | [`prismstudio.estimate.guidance`](<#prismstudio.estimate.guidance>)                                 | Aperiodic |
| Estimate        | Revision                      | ✔️ | [`prismstudio.estimate.revision`](<#prismstudio.estimate.revision>)                                 | Aperiodic |
| Estimate        | Surprise                      | ✔️ | [`prismstudio.estimate.surprise`](<#prismstudio.estimate.surprise>)                                 | Aperiodic |
| Estimate        | Recommendation                | ✔️ | [`prismstudio.estimate.recommendation`](<#prismstudio.estimate.recommendation>)                     | Aperiodic |
| Estimate        | Segment                       | ✔️ | [`prismstudio.estimate.segment`](<#prismstudio.estimate.segment>)                                   | Aperiodic |
| Estimate        | Industry                      | ✔️ | [`prismstudio.estimate.industry`](<#prismstudio.estimate.industry>)                                 | Aperiodic |
| Event           | Summary                       | ✔️ | [`prismstudio.event.summary`](<#prismstudio.event.summary>)                                         | Aperiodic Day |
| Event           | Earnings Call                 | ❌ | [`prismstudio.event.earnings_call`](<#prismstudio.event.earnings_call>)                             | Aperiodic Day |
| Index           | Index Level                   | ✔️ | [`prismstudio.index.level`](<#prismstudio.index.level>)                                             | Business Day |
| Index           | Index Share                   | ✔️ | [`prismstudio.index.share`](<#prismstudio.index.share>)                                             | Business Day |
| Index           | Index Weight                  | ✔️ | [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                           | Business Day |
| Security Master | Security Master Attribute     | ❌ | [`prismstudio.securitymaster.attribute`](<#prismstudio.securitymaster.attribute>)                   | Day |
| Reference       | Holiday                       | ❌ | [`prismstudio.reference.holiday`](<#prismstudio.reference.holiday>)                                 | Day |
| Reference       | Weekend                       | ❌ | [`prismstudio.reference.weekend`](<#prismstudio.reference.weekend>)                                 | Day |
| Reference       | Trading Hours                 | ❌ | [`prismstudio.reference.tradinghour`](<#prismstudio.reference.tradinghour>)                         | |
| Compnay         | Description                   | ❌ | [`prismstudio.company.description`](<#prismstudio.company.description>)                             | |
| Compnay         | Competitor                    | ❌ | [`prismstudio.company.competitor`](<#prismstudio.company.competitor>)                               | |
| Compnay         | Product                       | ❌ | [`prismstudio.company.product`](<#prismstudio.reference.product>)                                   | |
| Compnay         | Relationship                  | ❌ | [`prismstudio.company.relationship`](<#prismstudio.reference.relationship>)                         | |
| Transaction     | M&A                           | ✔️ | [`prismstudio.transaction.ma`](<#prismstudio.transaction.ma>)                                       | Aperiodic Day |
| Transaction     | Buyback                       | ❌ | [`prismstudio.transaction.buyback`](<#prismstudio.transaction.buyback>)                             | Aperiodic Day |
| ESG             | Environmental                 | ✔️ | [`prismstudio.esg.environmental`](<#prismstudio.esg.environmental>)                                 | Aperiodic Day |
| ESG             | Social                        | ✔️ | [`prismstudio.esg.social`](<#prismstudio.esg.social>)                                               | Aperiodic Day |
| ESG             | Governance                    | ✔️ | [`prismstudio.esg.governance`](<#prismstudio.esg.governance>)                                       | Aperiodic Day |
| ESG             | Diversity                     | ✔️ | [`prismstudio.esg.diversity`](<#prismstudio.esg.diversity>)                                         | Aperiodic Day |
| ESG             | Overall                       | ✔️ | [`prismstudio.esg.overall`](<#prismstudio.esg.overall>)                                             | Aperiodic Day |
| Economics       | Economics                     | ✔️ | [`prismstudio.economics.economics`](<#prismstudio.economics.economics>)                  | Aperiodic Day |









